==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/nl/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Lĳst nieuw) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "zet:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " bĳ:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Reeks nieuw "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Reeks ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "Niets"
#define CTR_DICT_BOOLEAN         "Ja of Nee"
#define CTR_DICT_TRUE            "Ja"
#define CTR_DICT_FALSE           "Nee"
#define CTR_DICT_NUMBER          "Getal"
#define CTR_DICT_STRING          "Tekst"
#define CTR_DICT_TASK      "Taak"
#define CTR_DICT_OBJECT          "Object"
#define CTR_DICT_ARRAY_OBJECT     "Reeks"
#define CTR_DICT_MAP_OBJECT      "Lĳst"
#define CTR_DICT_PROGRAM       "Programma"
#define CTR_DICT_FILE            "Bestand"
#define CTR_DICT_MOMENT      "Moment"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "nieuw"
#define CTR_DICT_EQUALS          "gelĳk:"
#define CTR_DICT_AND             "en:"
#define CTR_DICT_OR              "of:"
#define CTR_DICT_MODULO          "modulus:"
#define CTR_DICT_NOR             "noch:"
#define CTR_DICT_ONDO            "bĳ:doen:" 
#define CTR_DICT_TYPE            "type" 
#define CTR_DICT_ISNIL           "Niets?"
#define CTR_DICT_MYSELF          "mĳzelf"
#define CTR_DICT_DO              "doen"
#define CTR_DICT_DONE            "klaar"
#define CTR_DICT_IFFALSE         "nee:"
#define CTR_DICT_IFTRUE          "ja:"
#define CTR_DICT_WHILE           "zolang:"
#define CTR_DICT_MESSAGEARGS     "bericht:argumenten:"
#define CTR_DICT_MESSAGE         "bericht:"
#define CTR_DICT_LEARN           "leer:betekent:"
#define CTR_DICT_BREAK           "afbreken"
#define CTR_DICT_CONTINUE        "doorgaan"
#define CTR_DICT_ELSE            "anders:"
#define CTR_DICT_NOT             "niet"
#define CTR_DICT_TONUMBER        "getal"
#define CTR_DICT_ITONUMBER       "internationaal getal"
#define CTR_DICT_TOSTRING        "tekst"
#define CTR_DICT_CHAR_AT_SET     "letter:"
#define CTR_DICT_EITHEROR        "of:of:"
#define CTR_DICT_BY_SET       	 "per:"
#define CTR_DICT_FLOOR           "afgerond naar beneden"
#define CTR_DICT_CEIL            "afgerond naar boven"
#define CTR_DICT_ROUND           "afgerond"
#define CTR_DICT_ABS             "absoluut"
#define CTR_DICT_SQRT            "vierkantswortel"
#define CTR_DICT_POWER           "tot de macht:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "oneven?"
#define CTR_DICT_EVEN   	     "even?"
#define CTR_DICT_POS   	         "positief?" 
#define CTR_DICT_NEG   	         "negatief?" 
#define CTR_DICT_TOBOOL          "ja of nee?" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "tussen:en:" 
#define CTR_DICT_LENGTH	         "lengte" 
#define CTR_DICT_FROM_LENGTH	 "van:lengte:" 
#define CTR_DICT_TRIM	         "verwĳder omliggende spaties" 
#define CTR_DICT_AT              "bĳ:"
#define CTR_DICT_POSITION_SET    "positie:"
#define CTR_DICT_INDEX_OF        "zoek:" 
#define CTR_DICT_LAST_INDEX_OF	 "zoek laatste:" 
#define CTR_DICT_REPLACE_WITH	 "vervang:door:" 
#define CTR_DICT_SPLIT	         "opsplitsen:"
#define CTR_DICT_SKIP            "overslaan:" 
#define CTR_DICT_RUN             "start" 
#define CTR_DICT_APPLY_TO        "toepassen:" 
#define CTR_DICT_APPLY_TO_AND    "toepassen:en:" 
#define CTR_DICT_VALUE_SET       "gebruik:waarde:" 
#define CTR_DICT_ERROR	         "fout:" 
#define CTR_DICT_CATCH           "afhandelen:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "neem eerste"
#define CTR_DICT_COUNT           "aantal" 
#define CTR_DICT_JOIN            "samenvoegen:" 
#define CTR_DICT_POP             "neem laatste"
#define CTR_DICT_SORT            "sorteren:" 
#define CTR_DICT_PUT_AT          "zet:bĳ:" 
#define CTR_DICT_MAP             "lĳst:" 
#define CTR_DICT_EACH            "elk:"
#define CTR_DICT_WRITE           "schrĳf:"
#define CTR_DICT_PATH            "pad"
#define CTR_DICT_READ            "lezen"
#define CTR_DICT_APPEND          "toevoegen:"
#define CTR_DICT_PREPEND         "invoegen:"
#define CTR_DICT_EXISTS          "bestaat"
#define CTR_DICT_SIZE            "grootte"
#define CTR_DICT_DELETE          "verwĳderen"
#define CTR_DICT_USE_SET         "gebruik:" 
#define CTR_DICT_ARRAY            "reeks:"
#define CTR_DICT_END             "einde"
#define CTR_DICT_ARGUMENT	     "argument:" 
#define CTR_DICT_ARGUMENT_COUNT	 "aantal argumenten" 
#define CTR_DICT_WAIT_FOR_PASSW	 "vraag wachtwoord"
#define CTR_DICT_WAIT_FOR_INPUT	 "vraag" 
#define CTR_DICT_INPUT           "invoer" 
#define CTR_DICT_FLUSH           "spoelen"
#define CTR_DICT_WAIT            "wacht:" 
#define CTR_DICT_TIME	         "tĳd" 
#define CTR_DICT_RESPOND_TO      "reageer:" 
#define CTR_DICT_RESPOND_TO_AND  "reageer:en:" 
#define CTR_DICT_SHELL           "opdrachtregel:"
#define CTR_DICT_SWEEP           "vegen" 
#define CTR_DICT_MEMORY_LIMIT	 "geheugen:"
#define CTR_DICT_MEMORY      	 "geheugen" 
#define CTR_DICT_GC_MODE            "geheugenbeheer:"
#define CTR_DICT_HASH_WITH_KEY   "kluts:"
#define CTR_DICT_CHARACTERS      "letters"
#define CTR_DICT_QUALIFIER_SET         "kwalificatie:"
#define CTR_DICT_QUALIFIER   "kwalificatie"
#define CTR_DICT_NEW_SET         "nieuw:"
#define CTR_DICT_HOUR            "uur"
#define CTR_DICT_HOUR_SET        "uur:"
#define CTR_DICT_MINUTE_SET      "minuut:"
#define CTR_DICT_MINUTE          "minuut"
#define CTR_DICT_SECOND_SET      "seconde:"
#define CTR_DICT_SECOND          "seconde"
#define CTR_DICT_DAY             "dag"
#define CTR_DICT_DAY_SET         "dag:"
#define CTR_DICT_WEEK            "week"
#define CTR_DICT_WEEK_SET        "week:"
#define CTR_DICT_MONTH           "maand"
#define CTR_DICT_MONTH_SET       "maand:"
#define CTR_DICT_YEAR            "jaar"
#define CTR_DICT_RAW             "ruw"
#define CTR_DICT_YEAR_SET        "jaar:"
#define CTR_DICT_WEEK_DAY        "weekdag"
#define CTR_DICT_YEAR_DAY        "jaardag"
#define CTR_DICT_ZONE            "zone"
#define CTR_DICT_ZONE_SET        "zone:"
#define CTR_DICT_ADD_SET         "optellen:"
#define CTR_DICT_SUBTRACT_SET    "aftrekken:"
#define CTR_DICT_MULTIPLIER_SET  "vermenigvuldig met:"
#define CTR_DICT_DIVIDER_SET     "deel door:"
#define CTR_DICT_LAST            "laatste"
#define CTR_DICT_FIRST           "eerste"
#define CTR_DICT_SECOND_LAST     "een-na-laatste"
#define CTR_DICT_FILL_WITH       "vul:met:"
#define CTR_DICT_SPLICE          "vervang:lengte:door:"
#define CTR_DICT_VALUES          "waarden"
#define CTR_DICT_ENTRIES         "ingangen"
#define CTR_DICT_COMPARE_SET     "vergelĳk:"
#define CTR_DICT_HAS             "heeft:"
#define CTR_DICT_COPY            "kopieer"
#define CTR_DICT_CASE_DO         "geval:doen:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "hoofdletters" 
#define CTR_DICT_ASCII_LOWER_CASE                "kleine letters"
#define CTR_DICT_CONTAINS                        "bevat:"
#define CTR_DICT_APPLY_TO_AND_AND                "toepassen:en:en:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "instelling:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "instelling:is:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "reageer:en:en:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "reageer:en:en:en:"
#define CTR_DICT_CURRENT_TASK                      "dit codeblok"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "“"
#define CTR_DICT_QUOT_CLOSE                      "”"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "procedure"
#define CTR_DICT_TOOBJECT        "object"
#define CTR_DICT_PATH_OBJECT "Bestandslocatie"
#define CTR_DICT_CMD_OBJECT  "Instructie"
#define CTR_DICT_RECURSIVE "recursief"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/nl/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Lĳst nieuw) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "zet:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " bĳ:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Reeks nieuw "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Reeks ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "Niets"
#define CTR_DICT_BOOLEAN         "Ja of Nee"
#define CTR_DICT_TRUE            "Ja"
#define CTR_DICT_FALSE           "Nee"
#define CTR_DICT_NUMBER          "Getal"
#define CTR_DICT_STRING          "Tekst"
#define CTR_DICT_TASK      "Taak"
#define CTR_DICT_OBJECT          "Object"
#define CTR_DICT_ARRAY_OBJECT     "Reeks"
#define CTR_DICT_MAP_OBJECT      "Lĳst"
#define CTR_DICT_PROGRAM       "Programma"
#define CTR_DICT_FILE            "Bestand"
#define CTR_DICT_MOMENT      "Moment"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "nieuw"
#define CTR_DICT_EQUALS          "gelĳk:"
#define CTR_DICT_AND             "en:"
#define CTR_DICT_OR              "of:"
#define CTR_DICT_MODULO          "modulo:"
#define CTR_DICT_NOR             "noch:"
#define CTR_DICT_ONDO            "bĳ:doen:" 
#define CTR_DICT_TYPE            "type" 
#define CTR_DICT_ISNIL           "Niets?"
#define CTR_DICT_MYSELF          "mĳzelf"
#define CTR_DICT_DO              "doen"
#define CTR_DICT_DONE            "klaar"
#define CTR_DICT_IFFALSE         "nee:"
#define CTR_DICT_IFTRUE          "ja:"
#define CTR_DICT_WHILE           "zolang:"
#define CTR_DICT_MESSAGEARGS     "bericht:argumenten:"
#define CTR_DICT_MESSAGE         "bericht:"
#define CTR_DICT_LEARN           "leer:betekent:"
#define CTR_DICT_BREAK           "afbreken"
#define CTR_DICT_CONTINUE        "doorgaan"
#define CTR_DICT_ELSE            "anders:"
#define CTR_DICT_NOT             "niet"
#define CTR_DICT_TONUMBER        "getal"
#define CTR_DICT_ITONUMBER       "internationaal getal"
#define CTR_DICT_TOSTRING        "tekst"
#define CTR_DICT_CHAR_AT_SET     "letter:"
#define CTR_DICT_EITHEROR        "of:of:"
#define CTR_DICT_BY_SET       	 "per:"
#define CTR_DICT_FLOOR           "afgerond naar beneden"
#define CTR_DICT_CEIL            "afgerond naar boven"
#define CTR_DICT_ROUND           "afgerond"
#define CTR_DICT_ABS             "absoluut"
#define CTR_DICT_SQRT            "vierkantswortel"
#define CTR_DICT_POWER           "tot de macht:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "oneven?"
#define CTR_DICT_EVEN   	     "even?"
#define CTR_DICT_POS   	         "positief?" 
#define CTR_DICT_NEG   	         "negatief?" 
#define CTR_DICT_TOBOOL          "ja of nee?" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "tussen:en:" 
#define CTR_DICT_LENGTH	         "lengte" 
#define CTR_DICT_FROM_LENGTH	 "van:lengte:" 
#define CTR_DICT_TRIM	         "verwĳder omliggende spaties" 
#define CTR_DICT_AT              "bĳ:"
#define CTR_DICT_POSITION_SET    "positie:"
#define CTR_DICT_INDEX_OF        "zoek:" 
#define CTR_DICT_LAST_INDEX_OF	 "zoek laatste:" 
#define CTR_DICT_REPLACE_WITH	 "vervang:door:" 
#define CTR_DICT_SPLIT	         "opsplitsen:"
#define CTR_DICT_SKIP            "overslaan:" 
#define CTR_DICT_RUN             "start" 
#define CTR_DICT_APPLY_TO        "toepassen:" 
#define CTR_DICT_APPLY_TO_AND    "toepassen:en:" 
#define CTR_DICT_VALUE_SET       "gebruik:waarde:" 
#define CTR_DICT_ERROR	         "fout:" 
#define CTR_DICT_CATCH           "afhandelen:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "neem eerste"
#define CTR_DICT_COUNT           "aantal" 
#define CTR_DICT_JOIN            "samenvoegen:" 
#define CTR_DICT_POP             "neem laatste"
#define CTR_DICT_SORT            "sorteren:" 
#define CTR_DICT_PUT_AT          "zet:bĳ:" 
#define CTR_DICT_MAP             "lĳst:" 
#define CTR_DICT_EACH            "elk:"
#define CTR_DICT_WRITE           "schrĳf:"
#define CTR_DICT_PATH            "pad"
#define CTR_DICT_READ            "lezen"
#define CTR_DICT_APPEND          "toevoegen:"
#define CTR_DICT_PREPEND         "invoegen:"
#define CTR_DICT_EXISTS          "bestaat"
#define CTR_DICT_SIZE            "grootte"
#define CTR_DICT_DELETE          "verwĳderen"
#define CTR_DICT_USE_SET         "gebruik:" 
#define CTR_DICT_ARRAY            "reeks:"
#define CTR_DICT_END             "einde"
#define CTR_DICT_ARGUMENT	     "argument:" 
#define CTR_DICT_ARGUMENT_COUNT	 "aantal argumenten" 
#define CTR_DICT_WAIT_FOR_PASSW	 "vraag wachtwoord"
#define CTR_DICT_WAIT_FOR_INPUT	 "vraag" 
#define CTR_DICT_INPUT           "invoer" 
#define CTR_DICT_FLUSH           "spoelen"
#define CTR_DICT_WAIT            "wacht:" 
#define CTR_DICT_TIME	         "tĳd" 
#define CTR_DICT_RESPOND_TO      "reageer:" 
#define CTR_DICT_RESPOND_TO_AND  "reageer:en:" 
#define CTR_DICT_SHELL           "opdrachtregel:"
#define CTR_DICT_SWEEP           "vegen" 
#define CTR_DICT_MEMORY_LIMIT	 "geheugen:"
#define CTR_DICT_MEMORY      	 "geheugen" 
#define CTR_DICT_GC_MODE            "geheugenbeheer:"
#define CTR_DICT_HASH_WITH_KEY   "kluts:"
#define CTR_DICT_CHARACTERS      "letters"
#define CTR_DICT_QUALIFIER_SET         "kwalificering:"
#define CTR_DICT_QUALIFIER   "kwalificering"
#define CTR_DICT_NEW_SET         "nieuw:"
#define CTR_DICT_HOUR            "uur"
#define CTR_DICT_HOUR_SET        "uur:"
#define CTR_DICT_MINUTE_SET      "minuut:"
#define CTR_DICT_MINUTE          "minuut"
#define CTR_DICT_SECOND_SET      "seconde:"
#define CTR_DICT_SECOND          "seconde"
#define CTR_DICT_DAY             "dag"
#define CTR_DICT_DAY_SET         "dag:"
#define CTR_DICT_WEEK            "week"
#define CTR_DICT_WEEK_SET        "week:"
#define CTR_DICT_MONTH           "maand"
#define CTR_DICT_MONTH_SET       "maand:"
#define CTR_DICT_YEAR            "jaar"
#define CTR_DICT_RAW             "ruw"
#define CTR_DICT_YEAR_SET        "jaar:"
#define CTR_DICT_WEEK_DAY        "weekdag"
#define CTR_DICT_YEAR_DAY        "jaardag"
#define CTR_DICT_ZONE            "zone"
#define CTR_DICT_ZONE_SET        "zone:"
#define CTR_DICT_ADD_SET         "optellen:"
#define CTR_DICT_SUBTRACT_SET    "aftrekken:"
#define CTR_DICT_MULTIPLIER_SET  "vermenigvuldig met:"
#define CTR_DICT_DIVIDER_SET     "deel door:"
#define CTR_DICT_LAST            "laatste"
#define CTR_DICT_FIRST           "eerste"
#define CTR_DICT_SECOND_LAST     "een-na-laatste"
#define CTR_DICT_FILL_WITH       "vul:met:"
#define CTR_DICT_SPLICE          "vervang:lengte:door:"
#define CTR_DICT_VALUES          "waarden"
#define CTR_DICT_ENTRIES         "ingangen"
#define CTR_DICT_COMPARE_SET     "vergelĳk:"
#define CTR_DICT_HAS             "heeft:"
#define CTR_DICT_COPY            "kopieer"
#define CTR_DICT_CASE_DO         "geval:doen:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "hoofdletters" 
#define CTR_DICT_ASCII_LOWER_CASE                "kleine letters"
#define CTR_DICT_CONTAINS                        "bevat:"
#define CTR_DICT_APPLY_TO_AND_AND                "toepassen:en:en:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "instelling:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "instelling:is:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "reageer:en:en:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "reageer:en:en:en:"
#define CTR_DICT_CURRENT_TASK                      "dit codeblok"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "“"
#define CTR_DICT_QUOT_CLOSE                      "”"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "procedure"
#define CTR_DICT_TOOBJECT        "object"
#define CTR_DICT_PATH_OBJECT "Bestandslocatie"
#define CTR_DICT_CMD_OBJECT  "Instructie"
#define CTR_DICT_RECURSIVE "recursief"
